@@ -2,3 +2,5 @@
 //! Currently includes human NCBI gencode GRCh38. Automatically downloads the latest version of user's choice.
 
 pub mod ftp;
+pub mod ercc;
+pub mod phix;
\ No newline at end of file
