@@ -1,31 +1,27 @@
-use std::borrow::Borrow;
+
 use crate::utils::get::value::percentage;
-use std::collections::HashMap;
+
 use crate::charsets::PERCENTAGE_RANGE;
 
 use crate::charsets::ascii::*;
-use crate::utils::get::value;
+
 use crate::utils::get::value::ValueU8;
 use crate::utils::get::value::AsMutValueU8;
 use crate::utils::get::item::CodeItemU8;
 use crate::utils::mutate::item::MutCodeItemU8;
 
+
+
 /// Trait for checking specific criteria for a u8 of biological file origin. Types include sequence (nucleotide/amino acid) and quality (phred33/64/solexa, phred33 being all printable ascii).
 /// These should be used with closely with the is_ascii/make/to_ascii_lowercase/make/to_ascii_uppercase functions in standard rust.
 /// Additional functionality for common checks including has_n, has_gap, is_homopolymer, is_palindrome, etc.
 use crate::charsets::iupac::*;
 use crate::charsets::quality::*;
 
-pub const IS_WHAT_OPTIONS: [&str; 17] = 
-["is_iupac_nucleotide", "is_iupac_amino_acid", "is_iupac",
-"is_phred33", "is_phred64", "is_solexa",  
-"is_basic_dna", "is_basic_rna", "is_basic_amino_acid",
-"is_homopolymer", "is_homopolymer_n", "is_homopolymer_not_n",
-"has_n", "has_gap",
-"is_ascii_letters", "is_ascii_letters_uppercase", "is_ascii_letters_lowercase"
-];
-
 pub trait Check<K> {
+    // fn find_subseq(haystack: &[u8], needle: &[u8]) -> Option<usize> {
+    //     haystack.windows(needle.len()).position(|window| window == needle)
+    // }
         /// Checks if the sequence or quality u8 is less than or equal to the given length. Used to cut read to minimum length.
         fn is_at_least_length(&self, length: &usize) -> bool;
         /// Checks if the sequence or quality u8 is greater than or equal to the given length. Used to cut read to maximum length.
@@ -41,6 +37,9 @@ where
     T: AsRef<[K]>,
     K: PartialEq,
 {
+    // fn find_subseq(haystack: &[u8], needle: &[u8]) -> Option<usize> {
+    //     haystack.windows(needle.len()).position(|window| window == needle)
+    // }
         /// Checks if the sequence or quality u8 is less than or equal to the given length. Used to cut read to minimum length.
         fn is_at_least_length(&self, length: &usize) -> bool {
             self.as_ref().len() >= *length
@@ -370,6 +369,17 @@ pub fn validate_phred64_score_u8(quality_score: &u8) -> Result<bool, &'static st
     }
 }
 
+
+
+// pub const IS_WHAT_OPTIONS: [&str; 17] = 
+// ["is_iupac_nucleotide", "is_iupac_amino_acid", "is_iupac",
+// "is_phred33", "is_phred64", "is_solexa",  
+// "is_basic_dna", "is_basic_rna", "is_basic_amino_acid",
+// "is_homopolymer", "is_homopolymer_n", "is_homopolymer_not_n",
+// "has_n", "has_gap",
+// "is_ascii_letters", "is_ascii_letters_uppercase", "is_ascii_letters_lowercase"
+// ];
+
     // /// Validates whether is a valid something based on the boolean is_x smaller functions in this trait and returns a wrapped boolean. Example: check_u8(b"ACTG","is_basic_dna") returns a wrapped "true". Options for is_what are the names of the charset boolean functions:
     // /// is_basic_dna, is_phred33, is_basic_rna,  
     // /// The goal of this function would be to set is_what to a constant in the program, for example a program focused on illumina data might set a constant to phred33 and input as is_what, rather than having to call is_phred33 each time. This means we can easily make our program take phred33 or 64 by just changing the constant.
