@@ -7,32 +7,63 @@
 //! println!("{:?}", target);
 //! println!("{:?}", matching) // Returns the 0 based index;
 
+
 use crate::charsets::iupac::NUCLEOTIDE_COMPLEMENT_HASHMAP_U8;
-use std::collections::HashMap;
+
 use crate::charsets::quality::SANGER_HASHMAP_ENCODE_U8;
 use crate::charsets::quality::SANGER_HASHMAP_DECODE_U8;
 use crate::charsets::quality::PHRED33_HASHMAP_U8;
 use crate::charsets::quality::PHRED64_HASHMAP_U8;
 use crate::charsets::quality::PHRED33_HASHMAP_ENCODE_U8;
 use crate::charsets::quality::PHRED64_HASHMAP_ENCODE_U8;
-use std::iter::FromIterator;
-use std::convert::TryInto;
 
 
-use crate::utils::check::value::Check;
+
+
+
+
+
 
 pub trait GetItemU8<T> {
-    /// Cuts the read to a specific length
-    fn cut_to_length(&self, length: &usize) -> Vec<u8>;
+    /// Returns the reverse nucleotide complement
+    fn reverse_nucleotide_complement(&self) -> Vec<u8>;
+    /// Returns the nucleotide complement
+    fn nucleotide_complement(&self) -> Vec<u8>;
 }
 
 impl<T> GetItemU8<T> for T
 where
     T: AsRef<[u8]>,
 {
-    /// Cuts u8 to a specified length. Uses take to get the first x number of u8s so if the length is shorter will return the vector filled with None(). Should be used with check functions for length.
-    fn cut_to_length(&self, length: &usize) -> Vec<u8> {
-        self.as_ref().iter().take(*length).cloned().collect::<Vec<u8>>()
+    /// Returns the reverse nucleotide complement
+    fn reverse_nucleotide_complement(&self) -> Vec<u8> {
+        self.as_ref().iter()
+            .rev()
+            .map(|nt| NUCLEOTIDE_COMPLEMENT_HASHMAP_U8.get(nt).unwrap().to_owned())
+            .collect()
+    }
+    /// Returns the nucleotide complement
+    fn nucleotide_complement(&self) -> Vec<u8> {
+        self.as_ref().iter()
+            .map(|nt| NUCLEOTIDE_COMPLEMENT_HASHMAP_U8.get(nt).unwrap().to_owned())
+            .collect()
+    }
+}
+
+
+pub trait Get<T> {
+    /// Returns the index of the subsequence if present in self
+    fn find_subsequence(&self, subsequence: &[T]) -> Option<usize>;
+}
+
+impl<T> Get<T> for T
+where
+    T: AsRef<[T]>,
+    T: PartialEq, 
+{
+    /// Returns the index of the subsequence if present in self
+    fn find_subsequence(&self, subsequence: &[T]) -> Option<usize> {
+        self.as_ref().windows(subsequence.len()).position(|window| window == subsequence)
     }
 }
 
@@ -49,11 +80,6 @@ pub trait CodeItemU8<T> {
     fn encode_qual_phred64(&self) -> Vec<u8>;
     /// Returns the SANGER quality encoding from a SANGER quality score. The score is the u8 minus 33.
     fn encode_qual_sanger(&self) -> Vec<u8>;
-
-    /// Returns the nucleotide complement
-    fn nucleotide_complement(&self) -> Vec<u8>;
-    /// Returns the reverse nucleotide complement
-    fn reverse_nucleotide_complement(&self) -> Vec<u8>;
 }
 
 impl<T> CodeItemU8<T> for T
@@ -84,20 +110,6 @@ where
     fn encode_qual_sanger(&self) -> Vec<u8> {
         self.as_ref().iter().map(|q| SANGER_HASHMAP_ENCODE_U8.get(&q).unwrap().to_owned()).collect::<Vec<u8>>()
     }
-
-    /// Returns the nucleotide complement
-    fn nucleotide_complement(&self) -> Vec<u8> {
-        self.as_ref().iter()
-            .map(|nt| NUCLEOTIDE_COMPLEMENT_HASHMAP_U8.get(&nt).unwrap().to_owned())
-            .collect()
-    }
-    /// Returns the reverse nucleotide complement
-    fn reverse_nucleotide_complement(&self) -> Vec<u8> {
-        self.as_ref().iter()
-            .rev()
-            .map(|nt| NUCLEOTIDE_COMPLEMENT_HASHMAP_U8.get(nt).unwrap().to_owned())
-            .collect()
-    }
 }
 
 /// Returns CG positions in the given &[u8]
@@ -118,6 +130,7 @@ where
         .map(|(idx, _)| idx).collect::<Vec<usize>>()
 }
 
+
 // /// Creates a hashmap of the count of each position returned from a suffix array alignment using the suffix array crate. This only includes the start of the aligned section with no other information.
 // pub fn position_pileup(positions: &[u32]) -> HashMap<u32, u64> {
 //     let mut hashmap = HashMap::new();
